# Contributing to WordPress Publish

Thank you for your interest in contributing to the WordPress Publish module! This module allows Drupal content to be published to WordPress blogs, and we welcome contributions to improve its functionality and stability.

## Reporting Issues
- **Where to Report**: Use the Drupal.org issue queue for the project: [Insert Drupal.org project URL once created].
- **What to Include**:
  - Detailed steps to reproduce the issue.
  - Drupal and WordPress versions.
  - Relevant logs (e.g., `drush watchdog:show --type=wp_publish`).
  - Screenshots or error messages, if applicable.
- **Search First**: Check existing issues to avoid duplicates.

## Submitting Patches
- **Fork the Repository**: Fork the module’s Git repository on Drupal.org or GitHub (if mirrored).
- **Branching**: Create a feature or bugfix branch (e.g., `feature/add-queue-support` or `bugfix/fix-meta-mapping`).
- **Coding Standards**: Follow Drupal coding standards: https://www.drupal.org/docs/develop/standards
  - Use 2-space indents.
  - Include PHPDoc blocks for all classes, methods, and properties.
  - Run `phpcs` to check compliance:
    ```bash
    ./vendor/bin/phpcs --standard=Drupal modules/custom/wp_publish
    ```
- **Testing**: Add or update unit/functional tests in `tests/src/Unit` or `tests/src/Functional`.
  - Run tests with PHPUnit:
    ```bash
    ./vendor/bin/phpunit -c web/core modules/custom/wp_publish
    ```
- **Commit Messages**: Use clear, descriptive messages (e.g., “Add configurable media field support to settings form”).
- **Submit Patches**: Create a patch file and attach it to the relevant issue on Drupal.org:
  ```bash
  git diff > issue-1234.patch

## Feature Requests
- Propose Features: Open an issue tagged as “Feature request” with a detailed description.

- Discuss First: Engage with maintainers to confirm the feature aligns with the module’s scope.

## Code Review
- All patches are reviewed for functionality, standards, and security.

- Expect feedback within 1-2 weeks, depending on maintainer availability.

## Becoming a Maintainer
- Consistent contributors may be invited to become co-maintainers.
- Contact the current maintainer(s) via the issue queue to express interest.

## Questions?
- Reach out via the Drupal.org issue queue or Drupal Slack (#contribute channel).

Thank you for helping make WordPress Publish better!

