# WordPress Publish

Publishes Drupal content to a WordPress blog automatically or on a per-node basis, with flexible field mapping, taxonomy synchronization, media uploads, and bulk publishing capabilities.

## Features
- Publish nodes to WordPress via REST API, with automatic publishing when nodes are saved and published.
- Configure field mappings for title, content, taxonomy, media, and custom meta fields (e.g., map `field_summary` to WordPress `excerpt`).
- Sync taxonomy terms to WordPress categories, creating categories if they don’t exist.
- Upload images/files from a configurable Drupal media field to the WordPress media library, embedding them in post content.
- Bulk publish nodes using the Drush command `drush wpb`.
- Per-node publishing control via a checkbox on node forms.
- Admin configuration interface at Configuration > Web services > WordPress Publish.
- Error logging for debugging publishing issues.
- Drupal 12 readiness for future compatibility.

## Requirements
- Drupal 10.3, 11.0, or 12.0 (future-compatible).
- WordPress site with REST API enabled and Application Passwords plugin (recommended) or JWT Authentication.
- PHP 8.1 or higher (Drupal 10/11 requirement).
- Drupal modules: `node`, `taxonomy`, `file` (included as dependencies).
- Drush 10+ for bulk publishing.

## Installation
1. Install via Composer:
   ```bash
   composer require 'drupal/wp_publish:^1.0'
2. Enable the module: `drush en wp_publish`
3. Configure settings at `/admin/config/services/wp-publish`.

## Configuration
- Access settings at Configuration > Web services > WordPress Publish (/admin/config/services/wp-publish).
- Enter the WordPress site URL, username, and application password.
- Select content types to enable automatic publishing (e.g., article).
- Configure field mappings:
  -- **Title Field:** Map a Drupal field to the WordPress post title (default: title).
  -- **Content Field:** Map a Drupal field to the WordPress post content (default: body).
  -- **Taxonomy Field:** Select a Drupal taxonomy field to sync with WordPress categories (optional).
  -- **Media Field:** Choose a Drupal field (e.g., field_image) for uploading images/files to WordPress (optional).
  -- **Custom Meta Fields:** Map Drupal fields to WordPress custom meta in the format drupal_field:meta_key per line (e.g., field_summary:excerpt).
- Optionally, enable per-node publishing on node forms using the “Publish to WordPress” checkbox.

## Usage
- Single Node Publishing:
  -- Create or edit a node of an enabled content type.
  -- Ensure the “Publish to WordPress” checkbox is enabled (default: checked).
  -- Save and publish the node to send it to WordPress.
  -- Verify the post in WordPress, including mapped fields, categories, images, and custom meta.

- Bulk Publishing:
  --Publish all eligible nodes (published, wp_publish enabled) of a content type:
bash
drush wp-publish:bulk article
  -- Alias: drush wpb article.

- Debugging:
  -- Check logs for publishing successes or errors:
bash
drush watchdog:show --type=wp_publish

## Testing
- Automated Tests:
  -- Run unit and functional tests:
bash

./vendor/bin/phpunit -c web/core modules/custom/wp_publish/tests/src/Unit
./vendor/bin/phpunit -c web/core modules/custom/wp_publish/tests/src/Functional

  -- Manual Testing:
    ---Verify settings form configuration and validation.
    ---Test single node publishing with field mappings, taxonomy, media, and custom meta.
    --- Test bulk publishing with multiple nodes.
    --- Check error handling for invalid WordPress credentials or unreachable sites.

## Contributing
See CONTRIBUTING.md for guidelines on reporting issues, submitting patches, proposing features, and becoming a co-maintainer.

# Maintainers
- Bhavin Joshi - https://bhj.im/do
