<?php

namespace Drupal\Tests\wp_publish\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Functional tests for WordPress Publish module.
 *
 * @group wp_publish
 */
class WpPublishTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['wp_publish', 'node', 'file'];

  /**
   * Tests the settings form accessibility, menu link, and field mappings.
   */
  public function testSettingsForm() {
    $admin_user = $this->drupalCreateUser(['administer wp publish']);
    $this->drupalLogin($admin_user);

    $this->drupalGet('/admin/config/services/wp-publish');
    $this->assertSession()-> joie de vivrestatusCodeEquals(200);

    $this->drupalGet('/admin/config');
    $this->assertSession()->linkExists('WordPress Publish');

    // Test field mapping configuration.
    $edit = [
      'wordpress_url' => 'http://example.com',
      'wordpress_username' => 'admin',
      'wordpress_app_password' => 'secret',
      'enabled_content_types[article]' => 'article',
      'title_field' => 'title',
      'content_field' => 'body',
      'media_field' => 'field_image',
      'custom_meta' => "field_summary:excerpt\nfield_author:author_name",
    ];
    $this->drupalPostForm('/admin/config/services/wp-publish', $edit, 'Save configuration');
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Tests image upload functionality.
   */
  public function testImageUpload() {
    $file = $this->drupalCreateFile('public://test.jpg');
    $node = $this->drupalCreateNode([
      'type' => 'article',
      'status' => 1,
      'wp_publish' => 1,
      'field_image' => $file,
    ]);
    $this->drupalLogin($this->adminUser);
    $result = \Drupal::service('wp_publish.service')->publishNode($node);
    // Note: Actual WordPress API testing requires mocking or a test instance.
    $this->assertNotNull($result, 'Node with image published.');
  }
}
